*********************Important: MUST run ET_Tax after running this for accurate hhexp value*/

// Ethipian Rural Household Survey  1997	

/* 
This do file calculates the following variables for each household
	hid     : household (hh) identifier
	labor   : a dummy which shows whether a household contributes labor
	days    : the number of days contributed
	hhsize  : the number of hh members (normally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	No variable weight: "Sampling size in each village was governed by an attempt to obtain a self-weighting sample"
	cluster : is the indicator of smallest geographical unit, village or community  
	province: is the indicator of largest geographical unit, province or state
	weiclus : cluster level average of household weights
*/

clear 
cap log close
cd\IT
log using "Results\ET_Exp.log", replace

set memo 50m
set more off

use "OData\ET\Data\r4p5s1.DTA", clear

label var q51_1 "Did your household engage in community work in the last 12 (13 Ethiopian)months?"     	    
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

// dropping empty observations
drop if hid=="..."						   

keep     hid   q51_1 q51_3
sort     hid   q51_1

//  q51_1 q51_3 are answered by one ind per hh and it is empty for other members, so collapsing the data to construct household contribution variable
collapse q51_1 q51_3, by(hid)					                                      
g        labor     =  q51_1 
replace  labor     = 0 if q51_1 == 2   /* the answer "No" has been originally coded by 2, change to zero*/
label variable labor "labor contribution dummy"
ren      q51_3     days 
label variable days "Amount of labor contribution"

// replacing the days with 0 instead of missing when we know that hh did not contribute any labor
replace days  = 0 if days == . & labor ==0 

// marking all observations where two variables of labor and days contradict each other
g       contrad =0
replace contrad =1 if labor==0 & days>0 & days!=. 
replace contrad =1 if labor==1 & days==0
replace contrad =1 if labor==. & days>0 & days!=.
    
keep hid labor days contrad
sort hid
tempfile 01
save `01'

***********************************************************************************************************
use "OData\ET\Data\cons4.DTA", clear
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

replace  q1c     = 17    if q1c==18 | q1c==19 | q1c==20		                
/*These are all part of the same village*/

ren      cons4     hhexp 		 /*Variable "cons4": Total consumption/expenditures(food+non food)- 1 Month*/
drop hhsize4

sort hid
merge hid using `01', unique
tab  _
drop _
sort hid
tempfile 02
save `02'

**************************************************************************************Kids/adults
use "OData\ET\Data\age_sex_r4.dta",clear
g  hid   = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating the number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g hhsize = hhadults+hhkids+hhbabies                   /* This estimation is consistent with hhsize4, but covers more observations*/

sort hid
merge hid using `02', unique
tab _
drop _
sort hid
tempfile 03
save `03'

**************************************************************************************Worker
use "OData\ET\Data\11 3.3.99 roster.dta", clear     
g         hid    = (string(q1b,"%02.0f") +string(q1c,"%02.0f") + string(q1d,"%03.0f"))
/*
           3   Manual worker
           5   Weaver
          10   Farmer or family farm worker
          11   Domestic worker
          20   Manual worker
          21   Tailor
          22   Weaver
          23   Craftworker/Potter
          24   Blacksmith
          25   Foodseller
          26   Driver/Mechanic
          27   Skilled worker (Factory)
          30   Teacher
          31   Health worker
          32   Party official
          33   Soldier
          34   Trader
          40   Disabled
          50   Student
          51   Child, too young
          52   Child, help with domestic and farm work
          60   Looking for work
          70   Does not work/not looking for work
          80   Other

From the label book.
*/

recode activity (10=1) (11=0) (20/34=1) (40/80=0) (else=.), gen(worker)
collapse (sum) worker, by(hid)
sort  hid
merge hid using `03', unique
tab _
g cluster  = q1c
g	province = q1a			/*q1a is the region variable*/
g urban    = 0

************************************************************
keep  cluster hid hhsize urban labor days hh* worker province contrad 
order cluster hid hhsize urban labor days hh* worker
sort     hid
tempfile 04
save    `04'

// keeping list of hid with contradictions
keep if contrad ==1
keep hid
sort hid
save "Results\ET_contrad.dta", replace

// dropping observations with contradictions
use `04', clear
drop if contrad ==1
drop contrad
drop if labor == 1 & days == .

// as have the same process for all countries, constructing a placeholder weight, always equal to one, for Ethiopian data which does not have any weights*/
gen weight = 1

bys cluster: egen weiclus = mean(weight)
sort hid

save Results\ET_Exp_init.dta, replace
log close
