// Guatemala ENCOVI 2000

/* 
This do file calculates the following variables for each household
	hid     : household (hh) identifier
	labor   : a dummy which shows whether a household contributes labor (Here this variable includes only construction activities)
	hhsize  : the number of hh members (normally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh to be considered
	cluster : is the indicator of smallest geographical unit, village or community  
	province: is the indicator of largest geographical unit, province or state
	weiclus : cluster level average of household weights	
*/

/* Questionnaire has a question about money contribution in page 4, but the purpose of this "donation" is not clear enough, so it is not included. */

/* We have information about the amount of time contributed. The question asks the number of hours at the last day. 
So we use (hours*365/6) to find days per year, assuming 6 hours in a working day. This results in quite large numbers, 
with average of 39 days per year. Thus this information is not used.
*/

clear 
cap log close
cd\IT
log using "Results\GU_Exp.log", replace
set memo 50m
set more off

***************************************************************Labor 
use "OData\GU\Data\ECV04H02.DTA", clear 
ren hogar hid 

g labor = p02a01l == 1
label variable labor "labor contribution dummy"
sort hid
tempfile 02 
save `02' 

*************************************************************************************************** 
use "OData\GU\Data\CONSUMO5.DTA", clear

ren agreg3 pcexp_y		/*Where agreg3= comen3+casas3+aguas3+equip3+salud3+buses3+educa3+ayuda3+gasto3*/
ren factor weight			/* Factor = factor de expansin relacionado a lista.p */
ren hogar  hid

g urban 	= area == 1
g cluster = string(region,"%01.0f")+string(depto,"%02.0f")+string(mupio,"%02.0f")+string(sector,"%03.0f")
				
g province   = region 							
g pcexp      = pcexp_y/12    /*Convert to monthly*/

sort hid
merge hid using `02', unique
tab  _
drop _
sort hid
tempfile 03 
save `03'

***************************************************************Kids/adults
use "OData\GU\Data\ECV08P04.dta",clear
ren   hogar       hid
ren   edad    age
keep  hid  age 

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating the number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g hhsize = hhadults+hhkids+hhbabies                     

sort hid
merge hid using `03', unique
tab _
drop _
sort hid
tempfile 04 
save `04'

***************************************************************Workers
use "OData\GU\Data\ECV11P10", clear
ren hogar hid 
recode p10a01 (2=0) (9=.) ,gen(worker)
replace worker = 1 if p10a02 == 1
collapse (sum) worker, by(hid)
sort hid
merge hid using `04', unique
tab _

************************************************************
g            hhexp  = pcexp  * hhsize 
keep  hid hhsize weight urban labor hh* worker province cluster   
order hid hhsize weight urban labor hh* worker cluster*          
foreach var in labor{
sum `var' [aw=weight] 
sum `var' [aw=weight] if urban==1
sum `var' [aw=weight] if urban==0
}

bys cluster: egen weiclus = mean(weight)
sort hid 
save Results\GU_Exp.dta, replace
log close
