// Nicaragua "Encuesta Nacional de Hogares sobre Medicin de Niveles de Vida" 1998

/* 
This do file calculates the following variables for each household
	hid     : household(hh) indentifier
	labor/money : a dummy which shows whether a household contributes labor/money
	Any     : a dummy which shows whether a household contributes labor OR money
	days    : the number of days contributed
	dollars : the amount of money contributed in local money and for specific duration ( for Indonesia)
	hhsize  : the number of hh members (normally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh to be considered
	cluster : is the indicator of smallest geographical unit, village or community  
	weiclus : cluster level average of household weights
*/


clear 
set memo 50m

set more off
cd\IT
*******************************************************************************************************************************

use "OData\NI\Data\VIVIEND.DTA", clear
ren  i00   hid
g    urban = i05 == 1
g   cluster = real(string(i01,"%02.0f") + string(i02,"%02.0f")+ string(i03,"%03.0f")+ string(i04,"%05.0f"))


*************************************************************************************
// correcting for multi answer questions
qui foreach num in 1 2 3 4 5 6 7 {                  
	tostring vb570`num', gen(vb570`num'_s)
	g vb570`num'_1   = substr(vb570`num'_s, 1, 1)   
	g vb570`num'_2   = substr(vb570`num'_s, 2, 2)       if vb570`num' !=. 
	replace vb570`num'_2   = "."                        if vb570`num' ==. | vb570`num'_2 =="0" 
}

*****************************
/*People who didn't benefit are assuned not contributer (survey structured this way), this provides a lower bound*/
g     labor = 0 
replace labor = . if missing(vb5501) | missing(vb5502) |  missing(vb5503) |  missing(vb5504) |  missing(vb5505) |  missing(vb5506) |  missing(vb5507)
g     money = labor


// depending on kind of contribution, money or labor, separate the information
qui foreach num in 1 2 3 4 5 6 7 {
foreach ii in 1 2{
	replace labor   = 1        if vb570`num'_`ii' == "1" | vb570`num'_`ii' == "3" 
	replace money   = 1        if vb570`num'_`ii' == "2" | vb570`num'_`ii' == "4" | vb570`num'_`ii' == "5"
} 
}

g any = money == 1 | labor == 1


keep hid cluster urban *any *labor* *money* i01 i02
sort hid
tempfile 01
save `01'

*************************************************************************************************************************
use "OData\NI\Data\CONSUMO1"
ren  i00 hid

sort hid
merge hid using `01', unique
tab _
drop _

ren peso2     weight
ren consumo   pcexp
sort hid
tempfile 02
save `02'

*********************************************************************** Kids/adults 
use OData\NI\Data\DEMO.DTA, clear
ren   i00      hid
ren   p204a    age
keep  hid  age 

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid)
g hhsize = hhadults + hhkids + hhbabies                   
sort hid
merge hid using `02', unique
tab _

************************************************************
// calculating monthly household expenditure
g   hhexp   = pcexp*hhsize/12                  

keep  cluster hid hhsize weight urban *any* *labor* *money* hh* 
order cluster hid hhsize weight urban *any* *labor* *money* hh*


bys cluster: egen weiclus = mean(weight)
sort hid
save Results\NI_Exp.dta, replace
