// PANAMA (Encuesta de Niveles de Vida) 2003

/* 
This do file calculates the following variables for each household
	hid     : household(hh) indentifier
	labor/money   : a dummy which shows whether a household contributes labor/money
	Any     : a dummy which shows whether a household contributes labor OR money
	days    : the number of days contributed
	dollars : the amount of money contributed in local money and for specific duration ( for Indonesia)
	hhsize  : the number of hh members (noemally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh which has to be considered
	cluster : is the indicator of smallest geographical unit, village or community  
	weiclus : cluster level average of household weights
*/


clear 
set memo 50m
set more off
cd\IT

log using "Results\PA_Exp.log", replace
use OData\PA\Data\E03CS02.dta, clear
ren  form   hid

*********************************************************Contributions
g       labor     = csa1a == 1 
g       money     = csa1e == 1
g       any       = money == 1 | labor == 1

sort hid 
keep hid *any* *labor* *money* 
tempfile 01 
save `01'

**********************************************************************************************************************************************************
use "OData\PA\Data\E03Base.dta" 	
g 	 urban   = area == 1 		

g 	cluster_str = string(region,"%01.0f")+string(prov,"%02.0f")+string(dist,"%02.0f")+string(corr,"%02.0f")+string(urban,"%01.0f")
destring(cluster_str), gen(cluster)
g  	 cid     = string(region,"%01.0f")+string(prov,"%02.0f")+string(dist,"%02.0f")+string(corr,"%02.0f")+string(urban,"%01.0f")+string(upm,"%01.0f")

keep	 factor urban form cluster miembros cons2pc cid
ren 	 form     hid
ren 	 cons2pc  pcexp_y				
ren 	 factor   weight

sort hid
merge hid using `01', unique
tab  _
drop _
sort hid
tempfile 02
save `02'

***********************************************************************Kids/adults
use OData\PA\Data\E03PE07.DTA, clear
ren   form      hid
ren   p004    age

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// creating worker dummy
g worker = 0
replace worker = 1 if p701 == 1
replace worker = . if p701 == .
**Question only asked for those 10 years and older
replace worker = 0 if age < 9 

// calculating number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies (sum) worker=worker, by(hid)
g hhsize = hhadults+hhkids+hhbabies                   

sort hid
merge hid using `02', unique
tab _

************************************************************
// calculating monthly hh expenditure
g      hhexp = hhsize*(pcexp_y/12)			
keep  cluster hid hhsize worker weight urban *any* *labor* *money* hh* cid
order cluster hid hhsize worker weight urban *any* *labor* *money* hh*


bys cluster: egen weiclus = mean(weight)
sort hid
save "Results\PA_Exp.dta", replace
log close
