//Philippines 2003

/* 
This do file calculates the following variables for each household
	hid     : household(hh) indentifier
	labor   : a dummy which shows whether a household contributes labor
	days    : the number of days contributed
	hhsize  : the number of hh members (noemally constructed from roster data)
	hhadults: number of adult members of hh (define as be older than 14)
	hhkids  : number of kids in hh (define as be between 4 and 14)
	hhbabies: number of babies of hh (define as be younger than 4)
	worker  : number of workers per household
	hhexp   : monthly household expenditure
	urban   : equal to one if hh lives in urban area and 0 otherwise
	weight  : the weight of hh to be considered
	cluster : is the indicator of smallest geographical unit, village or community  
	_b      : indicating when we include only contribution toward construction activities
	weiclus : cluster level average of household weights
*/

clear
cap log close
cd\
cd\IT
log using "Results\PH_Participation.log", replace 
set memo 50m
set more off
use       "OData\PH\Data\hhnew.dta", clear

ren     id    hid
ren     hhwgt weight
ren barangay cluster
/*question e1ai has three option to indicate the three activities that household contributed to, choose the ones that are relevant*/
recode  e1ai_* (98=.) (888=.)                                          /* For consistency: e1ai_1 has missings instead of 888 */

g labor_b = 0
g labor   = 0
label variable labor "labor contribution dummy"

qui foreach var in 1 2 3{
	foreach num of numlist 51/53 60 70/79 81/83 101/106 110/118 131/132 140 150/152 160 170 180 300/304 {
		replace labor_b = 1 if e1ai_`var'==`num'
		replace labor   = 1 if e1ai_`var'==`num'
	}
      foreach num of numlist 1/8 13/15 20/26 29 41/45 50 {
		replace labor = 1 if e1ai_`var'==`num'
	}
}                             
/*Do this for all 3 because are allowed to list 3 different types of activities in which participate */ 
recode  e1aiii_* (.=0)        
/*Do this so sum correctly - households return a missing even if either the male or female did work but the other did not*/ 
/*Amount of time spent has been asked per gender of contributer, per hour over the last 6 month*/
                     
g       days = (e1aiii_m+e1aiii_f)*(2/6) if labor == 1     
/* 2 because make it annual and 6 because make it on day unit instead of hour, assuming 6 work hours per day*/ 
/* Have "if labor == 1" because the hours may correspond to activities not included in "labor" variable*/
/*This "days" may be overestimation as it includes other activities than the labor contribution if the household did at least one labor contribution activity*/

// marking observations where labor and days variables contradict each other
g       contrad =0
replace contrad =1 if labor==0 & days>0 & days!=. 
replace contrad =1 if labor==1 & days==0
replace contrad =1 if labor==. & days>0 & days!=.
keep labor* days hid weight contrad cluster
sort hid
tempfile 01 
save `01'

*********************************************
use "OData\PH\Final-expenditure.DTA", clear                                                                  
ren pcexp_m pcexp
ren id hid
ren barangay cluster			

sort hid 
merge hid using `01', unique 
tab _
drop _
sort hid
tempfile 02
save `02'

***********************************************************************Kids/Adults
use OData\PH\Data\memnew.DTA, clear
ren   id      hid
ren   b4      age
keep  hid     age province

// creating dummies for each age-group
g adults =  age>14
g kids   =  age<=14 & age>4
g babies =  age<=4

// calculating of the number of adults/kids/babies per hh
collapse (sum) hhadults=adults (sum) hhkids=kids (sum) hhbabies=babies, by(hid province)
g hhsize = hhadults + hhkids + hhbabies                   
sort hid
merge hid using `02', unique
tab _
drop _ 
sort hid
tempfile 03
save `03'

**************************************************************************Workers
use "OData\PH\Data\memnew.dta", replace
ren id hid
recode d1a20 (1=1) (2 8=0) (else=.), gen(worker) 
/*Option 8 was "not applicable" which included as a no, not a missing, because for purposes here these people are not wage earners 
(and there are a significant number of people answering this - 14%.)*/

collapse (sum) worker, by(hid)
sort hid
merge hid using `03', unique
tab _
g   urban  = 0				/*Have only rural households, create for consistency with other datasets*/

************************************************************
// calculating household expenditure
g     hhexp = hhsize* pcexp
sort     hid
tempfile 04
save    `04'

// keeping the list of hid with contradictions
keep if contrad ==1
keep hid
sort hid
save Results\PH_contrad.dta, replace

// dropping observations with contradictions
use `04', clear
drop if contrad ==1
drop contrad
replace days = 0 if labor ==0

keep  cluster hid hhsize weight urban *labor* days hh* worker province
order cluster hid hhsize weight urban *labor* days hh* worker 

bys cluster: egen weiclus = mean(weight)
sort hid
sum labor labor_* days [aw=weight]
sum days [aw=weight] if labor_b==1
sum days [aw=weight] if labor  ==1


save Results\PH_Exp, replace
log close
