/* "Figure 1: Comparison of formal and informal taxes" */

clear
cap clear matrix
set mem 300m

set more off

clear
cap log close
cd\

set memo 50m
set more off
do "IT\DoFiles Public\0. AdoFiles\fanreg.ado" 
cd\IT\Results

**********************************************************************
// country name variables 
gl AL_country			= "Albania"
gl ET_country			= "Ethiopia"
gl ID07_country		= "Indonesia 2007"
gl PH_country			= "Philippines"
gl V02_country		= "Vietnam 2002"


gl N = 0

// parameters chosen to calculate the Equivalent to Scale (ES) households size based on Deaton and Olken works
gl alpha_s = 0.5
gl alpha_l = 0.6
gl teta    = 0.85


global rep_fanreg = 1
	
// list of countries considered for analysis
gl country_list ID07 PH AL ET V02

foreach cty in $country_list {	
	// importing necessary variables
	use "`cty'_Tax.dta", clear
	sort hid
	merge hid using "`cty'_Exp.dta", unique
	tab   _
	drop  _
	merge hid using "`cty'_ind_wage_predicted.dta", sort
	tab _
	drop _


	// expenditure variable
	g   logESexp   = log(hhexp/((hhadults+$alpha_l*hhkids+$alpha_s*hhbabies)^$teta))

	summ logESexp, detail
	return list

	// dropping expenditure outliers
	gen pctl_1 = .
	gen pctl_99 = .
	replace pctl_1  = r(p1) 
	replace pctl_99 = r(p99)
	drop if logESexp < pctl_1
	drop if logESexp > pctl_99
	drop pctl*

	//  ratio of direct tax over expenditure
	g	r_tot_dir_tax  =   100 * (tot_dir_tax/(12*hhexp))
	//  ratio of indirect tax over expenditure
	g r_tot_indir_tax  =   100 * (tot_indir_tax/(12*hhexp))
	//  ratio of total formal tax over expenditure
	g	r_tot_tax  =   100 * (tot_tax/(12*hhexp))


	// ratio of days contributed over total number of yearly workings days per household
	g       	r_lab_infor_days  = 100 * (days/(250*worker))
	codebook 	r_lab_infor_days
	// dropping extreme days contribution obs
	drop if 	r_lab_infor_days > 50 & r_lab_infor_days < .


	*********************************************************************************************************************************************************Part 2: informal taxes
	// monetized labor part of contribution			    	
	** 21.7 work days a month (30.4375*5/7); labor informal tax monetization: (total days in a year contributed by HH) * (monthly avg. HH wage/possible work days per month) = total monetary value of days contributed in a year; then divide by yearly expenditure and multiply by 100
	g	lab_infor_tax  = ((days*HHwage_Av_hat)/ 21.7)
		
	// account for obs in which hh wage is missing but no contribution		
	replace lab_infor_tax = 0 if days == 0 
	g	r_lab_infor_tax  = 100 * (lab_infor_tax / (12*hhexp))
	
	// dropping extreme monetized labor contribution obs	
	drop if r_lab_infor_tax > 50 & r_lab_infor_tax < .
	
	// dropping 2 remaining problematic obs. (assuming misentry)	
	if "`cty'" == "V02"{
		drop if r_tot_dir_tax > 100 & r_tot_dir_tax < .
	}

	fanreg r_tot_tax			logESexp, cluster(cluster) bw(3) reps($rep_fanreg) ytitle(Total formal tax/HH. Expenditure) xtitle(Equivalent Scale Expenditure)		ygen(temp_r_tot_tax_y) 			xgen(temp_r_tot_tax_x)
	fanreg r_tot_dir_tax	logESexp, cluster(cluster) bw(3) reps($rep_fanreg) ytitle(Direct tax/HH. Expenditure)       xtitle(Equivalent Scale Expenditure)		ygen(temp_r_tot_dir_tax_y)	xgen(temp_r_tot_dir_tax_x)

	capture confirm variable dollars
		
	// countries for which have monetary contribution info
	if !_rc {
 		// ratio of monetary part of contribution over expenditure
		g				r_mon_infor_tax = 100 * (dollars/(12*hhexp))
		// total value of contribution
		g				r_infor_tax = r_lab_infor_tax + r_mon_infor_tax

		fanreg	r_infor_tax logESexp, cluster(cluster) bw(3) reps($rep_fanreg) ytitle(Total informal tax/HH. Expenditure) xtitle(Equivalent Scale Expenditure) ygen(temp_r_infor_tax_y) xgen(temp_r_infor_tax_x)
	}
		
	// countries for which have labor contribution info only
	else{
		// total value of contribution
		g				r_infor_tax = r_lab_infor_tax
			
		fanreg	r_infor_tax logESexp, cluster(cluster) bw(3) reps($rep_fanreg)   ytitle(Total informal tax/HH. Expenditure) xtitle(Equivalent Scale Expenditure)    ygen(temp_r_infor_tax_y) xgen(temp_r_infor_tax_x)
	}

	label var temp_r_infor_tax_y 		"Informal taxes"
	label var temp_r_tot_tax_y 			"Total formal taxes"
	label var temp_r_tot_dir_tax_y 	"Direct formal taxes"

	twoway (histogram logESexp, color(bluishgray) yaxis(2)) (line temp_r_infor_tax_y temp_r_infor_tax_x, sort lw(thick) yaxis(1)) (line temp_r_tot_dir_tax_y temp_r_tot_dir_tax_x,sort lp(dash) lw(thick) yaxis(1)) (line temp_r_tot_tax_y temp_r_tot_tax_x,sort lc(gs8) lp(shortdash)lw(thick) yaxis(1)), title($`cty'_country) ytitle("% of expenditure") xtitle("Log equivalent expenditure") ylabel(#5) legend(order(2 4 3 1))  saving(Figure1_`cty', replace)
	drop temp*
}

// combine individual country graphs into single figure
graph combine Figure1_AL.gph Figure1_ET.gph Figure1_ID07.gph Figure1_PH.gph Figure1_V02.gph, xsize(10) ysize(6) col(3) altshrink
graph save Figure1_combined, replace



cd\
cd\IT
