/*"Table 10: Decisions about informal tax payments"*/

cd\

cd IT
clear
cap clear matrix
set more off
set mem 400m


*****Kecamatan type info
use OData\ID07\Data3\ea_list.dta, clear
cap drop *nm
g        cc = prov + kabu + keca
destring cc, generate(dd) ignore(".")
format   dd %15.0f

// "type" variable is "CCT community and household kecamatans"
keep dd type

order dd
sort dd
tempfile type
save `type'



*****Household info

use OData\ID07\Data3\R.dta, clear

g        cc   = string(rlk01_cd,"%02.0f") + string(rlk02_cd,"%02.0f") +string(rlk03_cd,"%03.0f") 
destring cc,    generate(dd) ignore(".")
format   dd %15.0f
rename rid hid

sort dd
merge dd using `type', uniqusing
tab _m
keep if _m == 3
drop _m


// keeping only generasi kecamatan
ren type SamplingMethod
keep if SamplingMethod == 3

gen row_num = .
gen var_name = ""
gen hh_var_mean = .
local count = 1


** Q1: Who makes decisions about which households participate?
multparse rpm18 part

gen part_sample = (part_A == 1 | part_B == 1 | part_C == 1 | part_D == 1 | part_E == 1 | part_F == 1 | part_G == 1 | part_H == 1 | part_I == 1 | part_V == 1)

gen q1_head = (part_A == 1 | part_B == 1 | part_C == 1)
gen q1_meeting = (part_D ==1 | part_E == 1 | part_F == 1)
gen q1_self = (part_G == 1)

foreach x in q1_head q1_meeting q1_self{ 
	summ `x' if part_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace hh_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}	

** Q2: Who determines how much is expected from each household?
multparse rpm19 expect

gen expect_sample = (expect_A == 1 | expect_B == 1 | expect_C == 1 | expect_D == 1 | expect_E == 1 | expect_F == 1 | expect_G == 1 | expect_H == 1 | expect_I == 1 | expect_V == 1)

gen q2_head = ( expect_A == 1 | expect_B == 1 | expect_C == 1)
gen q2_meeting = (expect_D ==1 | expect_E == 1 | expect_F == 1)
gen q2_self = (expect_G == 1)

foreach x in q2_head q2_meeting q2_self{ 
	summ `x' if expect_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace hh_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}	

**  Q3: What is the sanction imposed on a household if they do not participate?
multparse rpm20 sanction

gen sanction_sample = (sanction_A == 1 | sanction_B == 1 | sanction_C == 1 | sanction_D == 1 | sanction_E == 1 | sanction_F == 1 | sanction_G == 1 | sanction_V == 1 | sanction_W == 1)

gen q3_replacetime = (sanction_A == 1)
gen q3_materialfood = (sanction_B == 1)
gen q3_replaceperson = (sanction_C ==1)
gen q3_payperson = (sanction_D == 1)
gen q3_payfine = (sanction_E == 1)
gen q3_notallow = (sanction_F == 1)
gen q3_exclude = (sanction_G == 1)
gen q3_nospecified = (sanction_W == 1)

foreach x in q3_replacetime q3_materialfood q3_replaceperson q3_payperson q3_payfine q3_notallow q3_exclude q3_nospecified{ 
	summ `x' if sanction_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace hh_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}	


** Q4: If applicable, who determines this sanction?
multparse rpm21 determ

gen determ_sample = (determ_A == 1 | determ_B == 1 | determ_C == 1 | determ_D == 1 | determ_E == 1 | determ_F == 1 | determ_G == 1 | determ_H == 1 | determ_I == 1 | determ_V == 1)

gen q4_head = (determ_A == 1 | determ_B == 1 | determ_C == 1)
gen q4_meeting = (determ_D == 1 | determ_E == 1 | determ_F == 1)
gen q4_self = (determ_G == 1)

foreach x in q4_head q4_meeting q4_self{ 
	summ `x' if determ_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace hh_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}

drop if row_num == .
keep row_num var_name hh_var_mean
sort row_num var_name
tempfile hh_vals
save `hh_vals'




*****Village head info

use OData\ID07\Data3\L.dta, clear

g        cc   = string(llk01_cd,"%02.0f") + string(llk02_cd,"%02.0f") +string(llk03_cd,"%03.0f") 
destring cc,    generate(dd) ignore(".")
format   dd %15.0f

sort dd
merge dd using `type', uniqusing
tab _m
keep if _m == 3
drop _m


// keeping only generasi kecamatan
ren type SamplingMethod
keep if SamplingMethod == 3

gen row_num = .
gen var_name = ""
gen villhead_var_mean = .
local count = 1


** Q1: Who makes decisions about which households participate?
multparse lpmd01 part

gen part_sample = (part_A == 1 | part_B == 1 | part_C == 1 | part_D == 1 | part_E == 1 | part_F == 1 | part_G == 1 | part_H == 1 | part_I == 1)
** No obs with "part_V == 1", else would include in definition of sample

gen q1_head = (part_A == 1 | part_B == 1 | part_C == 1)
gen q1_meeting = (part_D ==1 | part_E == 1 | part_F == 1)
gen q1_self = (part_G == 1)

foreach x in q1_head q1_meeting q1_self{ 
	summ `x' if part_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace villhead_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}	

** Q2: Who determines how much is expected from each household?
multparse lpmd02 expect

gen expect_sample = (expect_A == 1 | expect_B == 1 | expect_C == 1 | expect_D == 1 | expect_E == 1 | expect_F == 1 | expect_G == 1 | expect_H == 1 | expect_I == 1 | expect_V == 1)

gen q2_head = ( expect_A == 1 | expect_B == 1 | expect_C == 1)
gen q2_meeting = (expect_D ==1 | expect_E == 1 | expect_F == 1)
gen q2_self = (expect_G == 1)

foreach x in q2_head q2_meeting q2_self{ 
	summ `x' if expect_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace villhead_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}	

**  Q3: What is the sanction imposed on a household if they do not participate?
multparse lpmd03 sanction

gen sanction_sample = (sanction_A == 1 | sanction_B == 1 | sanction_C == 1 | sanction_D == 1 | sanction_E == 1 | sanction_F == 1 | sanction_G == 1 | sanction_V == 1 | sanction_W == 1)

gen q3_replacetime = (sanction_A == 1)
gen q3_materialfood = (sanction_B == 1)
gen q3_replaceperson = (sanction_C ==1)
gen q3_payperson = (sanction_D == 1)
gen q3_payfine = (sanction_E == 1)
gen q3_notallow = (sanction_F == 1)
gen q3_exclude = (sanction_G == 1)
gen q3_nospecified = (sanction_W == 1)

foreach x in q3_replacetime q3_materialfood q3_replaceperson q3_payperson q3_payfine q3_notallow q3_exclude q3_nospecified{ 
	summ `x' if sanction_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace villhead_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}	


** Q4: If applicable, who determines this sanction?
multparse lpmd04 determ

gen determ_sample = (determ_A == 1 | determ_B == 1 | determ_C == 1 | determ_D == 1 | determ_E == 1 | determ_F == 1 | determ_G == 1 | determ_H == 1 | determ_I == 1 | determ_V == 1)

gen q4_head = (determ_A == 1 | determ_B == 1 | determ_C == 1)
gen q4_meeting = (determ_D == 1 | determ_E == 1 | determ_F == 1)
gen q4_self = (determ_G == 1)

foreach x in q4_head q4_meeting q4_self{ 
	summ `x' if determ_sample == 1, d
	replace row_num = `count' in `count'
	replace var_name = "`x'" in `count'
	replace villhead_var_mean = 100 * r(mean) in `count'
	local count = `count' + 1
}

drop if row_num == .
keep row_num var_name villhead_var_mean
sort row_num var_name

merge row_num var_name using `hh_vals'
tab _m
drop _m

order row_num var_name hh_var_mean villhead_var_mean
sort row_num


outsheet var_name hh_var_mean villhead_var_mean using Results\table10_decisions.out, replace

