/* "Table 2: Summary statistics" */


clear
cap log close

set memo 50m
set more off
cd\IT\Results

// Country name variables
gl AL_country  	= "Albania"
gl ET_country  	= "Ethiopia"
gl GU_country  	= "Guatemala"
gl ID07_country = "Indonesia 2007"
gl NG04_country = "Nigeria 2004"
gl NI_country  	= "Nicaragua"
gl PA_country 	= "Panama"
gl PH_country 	= "Philippines"
gl v02_country	= "Vietnam 2002"
gl ZA_country  	= "Zambia"

// GDP values
gl AL_gdp  	= 4731
gl ET_gdp  	= 814
gl GU_gdp  	= 4048
gl ID07_gdp = 3423
gl NI_gdp  	= 2910
gl NG04_gdp	= 941
gl PA_gdp  	= 6129
gl PH_gdp  	= 4250
gl v02_gdp 	= 2274	
gl ZA_gdp  	= 774

// Exchange rates
gl AL_exr  	= 0.01769 / 10    /*data in oldlek = 0.1 newlek*/    
gl ET_exr  	= 0.87969
gl GU_exr  	= 0.30188
gl ID07_exr	= 0.00028
gl NI_exr  	= 0.36503
gl NG04_exr	= 0.01288
gl PA_exr  	= 1.47758
gl PH_exr  	= 0.07890
gl v02_exr 	= 0.00034 * 1000	/*data in thousand dong*/
gl ZA_exr  	= 0.00132

gl N = 0
*********************************************************

gl country_list      AL ET GU ID07 NI NG04 PA PH v02 ZA


foreach cty in $country_list {
	use "`cty'_ind_data",clear

	// keeping the household heads' data
	keep if head ==1

	// calculating average age of all heads of households
	collapse (mean) a_age_hHH = age a_edu_hHH = education_y [aw = weight]

	g country = "$`cty'_country"

	sort country
	tempfile 02
	save    `02'  
	***************************************************
	use "`cty'_Exp.dta", clear

	// constructing a placeholder weight always equal to one for Ethiopian data, which does not have any weights
	capture confirm variable weight
	if _rc {
		g weight = 1 
	}

	// per year per capita PPP 2000$ expenditure
	g   expPYPCPPP = 12*(hhexp/hhsize)*$`cty'_exr
	label var expPYPCPPP "exp per year per capita PPP 2000$"

	// other country level averages
	collapse (mean) a_hhsize = hhsize a_worker = worker  a_urban = urban a_expPYPCPPP = expPYPCPPP [aw=weight]
	
	g a_gdp   = $`cty'_gdp
	g country = "$`cty'_country"

	sort country
	merge country using `02', unique
	tab _
	drop _

	keep  country a_hhsize a_worker a_expPYPCPPP a_gdp a_urban a_age_hHH a_edu_hHH
	order country a_hhsize a_worker a_expPYPCPPP a_gdp a_urban a_age_hHH a_edu_hHH

	if $N == 1{
		append using `00'
	}
	gl N=1
	
	tempfile 00
	save    `00' 
}

sort country
outsheet using table2, replace
save table2.dta, replace

cd\
cd\IT

