/* "Table 3: Summary of informal tax payments" */

clear
cap log close
cd\

set memo 50m
set more off
cd\IT
do "DoFiles Public\0. AdoFiles\maketable3.ado" 
do "DoFiles Public\0. AdoFiles\maketable3WSD.ado" 
cd\IT\Results

**********************************************************************
// Country name variables 
gl   AL_country  = "Albania"
gl   ET_country  = "Ethiopia"
gl   GU_country  = "Guatemala"
gl ID07_country  = "Indonesia 2007"
gl NG04_country  = "Nigeria 2004"
gl   NI_country  = "Nicaragua"
gl   PA_country  = "Panama"
gl   PH_country  = "Philippines"
gl  V02_country  = "Vietnam 2002"
gl   ZA_country  = "Zambia"

// Recall periods
gl   AL_rp  = "1 year"
gl   ET_rp  = "1 year"
gl   GU_rp  = "1 year"
gl ID07_rp  = "1 year"
gl NG04_rp  = "unknown"
gl   NI_rp  = "Nicaragua"
gl   PA_rp  = "1 year"
gl   PH_rp  = "6 months"
gl  V02_rp  = "1 year"
gl   ZA_rp  = "5 years"

// Exchange rates
gl AL_exr  = 0.01769 / 10    /*data in oldlek = 0.1 newlek*/    
gl ET_exr  = 0.87969
gl GU_exr  = 0.30188
gl ID07_exr= 0.00028
gl NI_exr  = 0.36503
gl NG04_exr= 0.01288
gl PA_exr  = 1.47758
gl PH_exr  = 0.07890
gl V02_exr = 0.00034 * 1000	/*data in thousand dong*/
gl ZA_exr  = 0.00132


gl N = 0

*********************************************************
gl country_list   PH AL ET GU ID07 PA NG04 V02 NI ZA 


foreach cty in $country_list{
	// loading data (already excluding implausible obs)
	use "`cty'_keeplist.dta", clear
	disp "****$`cty'_country****"

	// recall periods
	if $N == 0{
		maketable3 using table3_dropobs, rhs(Recal Period) varcol($`cty'_country) name ($`cty'_rp) replace
		gl N = 1
	}
	else{
		maketable3 using table3_dropobs, rhs(Recal Period) varcol($`cty'_country) name ($`cty'_rp) append
	}

	// constructing a placeholder weight always equal to one for Ethiopian data, which does not have any weights 
	capture confirm variable weight
	if _rc {
		g weight = 1 
	}
	
	************************************
	capture confirm variable any
	
 	// for countries with only labor contribution info
 	if _rc {
		g any = labor				
	}

	************************************
	// Panel A values
	qui sum any [aw=weight] , d
	if $N == 0{
		maketable3 using table3_dropobs, rhs(any) varcol($`cty'_country) replace
		gl N = 1
	}
	else{
		maketable3 using table3_dropobs, rhs(any) varcol($`cty'_country) append
	}
	qui sum any [aw=weight] if urban==0 , d
	maketable3 using table3_dropobs, rhs(any Rural)  varcol($`cty'_country) append
	qui sum any [aw=weight] if urban==1 , d
		maketable3 using table3_dropobs, rhs(any Urban) varcol($`cty'_country) append	

}

foreach cty in $country_list{
	// loading data (already excluding implausible obs)
	use "`cty'_keeplist.dta", clear
	disp "****$`cty'_country"

	capture confirm variable weight
  if _rc {
		g weight = 1  /*placeholder value for Ethiopia*/
	}

  ************************************
	// Panel B "Any labor payment"
	qui sum labor [aw=weight] , d
		maketable3 using table3_dropobs, rhs(labor)       varcol($`cty'_country) append
	qui sum labor [aw=weight] if urban==0 , d
		maketable3 using table3_dropobs, rhs(labor rural) varcol($`cty'_country) append
	qui sum labor [aw=weight] if urban==1 , d
		maketable3 using table3_dropobs, rhs(labor urban) varcol($`cty'_country) append
	
	************************************
	// Panel B "Any money payment"
	capture confirm variable money
	if !_rc {
		replace money = money
		qui sum money [aw=weight] , d
			maketable3 using table3_dropobs, rhs(money)       varcol($`cty'_country) append
		qui sum money [aw=weight] if urban==0 , d
			maketable3 using table3_dropobs, rhs(money Rural) varcol($`cty'_country) append
		qui sum money [aw=weight] if urban==1 , d
			maketable3 using table3_dropobs, rhs(money Urban) varcol($`cty'_country) append
	}
}

***************************************************************************************
foreach cty in $country_list{
	// loading data (already excluding implausible obs)
	use "`cty'_keeplist.dta", clear
	disp "****$`cty'_country"

	capture confirm variable weight
  if _rc {
		g weight = 1  /*placeholder value for Ethiopia*/
	}
	
	************************************
	// Panel B "Amount of labor payment (in days)"
	capture confirm variable days
	if !_rc {
		qui sum days [aw=weight] , d
			maketable3WSD using table3_dropobs, rhs(days)       varcol($`cty'_country) append
		qui sum days [aw=weight] if urban==0 , d
			maketable3WSD using table3_dropobs, rhs(days Rural) varcol($`cty'_country) append
		qui sum days [aw=weight] if urban==1 , d
			maketable3WSD using table3_dropobs, rhs(days Urban) varcol($`cty'_country) append
	
	********************************
	// Panel B "Conditional amount of labor payment (in days)"	
		qui sum days [aw=weight] if labor==1, d
			maketable3WSD using table3_dropobs, rhs(days conditional)       varcol($`cty'_country) append
		qui sum days [aw=weight] if labor==1 & urban==0 , d
			maketable3WSD using table3_dropobs, rhs(days conditional Rural) varcol($`cty'_country) append
		qui sum days [aw=weight] if labor==1 & urban==1 , d
			maketable3WSD using table3_dropobs, rhs(days conditional Urban) varcol($`cty'_country) append
	}	

	********************************
	// Panel C "Amount of money payment (in 2000 PPP US$)"	
	capture confirm variable dollars
	if !_rc {
		replace dollars = dollars * $`cty'_exr
		qui sum dollars [aw=weight] , d
			maketable3WSD using table3_dropobs, rhs(dollars)       varcol($`cty'_country) append
		qui sum dollars [aw=weight] if urban==0 , d
			maketable3WSD using table3_dropobs, rhs(dollars Rural) varcol($`cty'_country) append
		qui sum dollars [aw=weight] if urban==1 , d
			maketable3WSD using table3_dropobs, rhs(dollars Urban) varcol($`cty'_country) append
	
	********************************
	// Panel C "Conditional amount of money payment (in 2000 PPP US$)"	
		qui sum dollars [aw=weight] if money==1, d
			maketable3WSD using table3_dropobs, rhs(dollars conditional)       varcol($`cty'_country) append
		qui sum dollars [aw=weight] if money==1 & urban==0 , d
			maketable3WSD using table3_dropobs, rhs(dollars conditional Rural) varcol($`cty'_country) append
		qui sum dollars [aw=weight] if money==1 & urban==1 , d
			maketable3WSD using table3_dropobs, rhs(dollars conditional Urban) varcol($`cty'_country) append
	}
} 


**** Panel B "Both money and labor payments"  

// list of countries considered for this analysis (those with both labor and monetary contribution info)
	gl country_list ID07 PA V02 NI ZA 

	local first = 1
	foreach cty in $country_list {
		// loading data (already excluding implausible obs)
		use "`cty'_keeplist.dta", clear
			
		gen str title = ""
		gen `cty'_share_total = .		
		gen `cty'_share_rural = .
		gen `cty'_share_urban = .
			

		if "`cty'" == "ID07" | "`cty'" == "PA" | "`cty'" == "V02" | "`cty'" == "NI" |"`cty'" == "ZA"{
			// categorize as contributing both money & labor or not
			gen both_contr = 1 if labor == 1 & money == 1
			replace both_contr = 0 if labor == 0 | money == 0
					
			replace title = "Both Contribution" in 1
			
			// country level averages
			summ both_contr [aw=weight]
				replace `cty'_share_total = r(mean) in 1		
			summ both_contr [aw=weight] if urban == 0
				replace `cty'_share_rural= r(mean) in 1	
			summ both_contr [aw=weight] if urban == 1
				replace `cty'_share_urban = r(mean) in 1		
		}			
	
		// combining all countries' results info into single table
		if "`first'" == "1"{
			outsheet title `cty'_share_total `cty'_share_rural `cty'_share_urban using table3_contr_stats_dropobs in 1, replace
		}
		else{
			outsheet title `cty'_share_total `cty'_share_rural `cty'_share_urban using table3_contr_stats_`cty'_dropobs in 1, replace			
			appendfile table3_contr_stats_`cty'_dropobs.out table3_contr_stats_dropobs.out
		}
	
		local first = 0	
		save `cty'_contr_stats, replace
	}

cd\
cd\IT

